DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_cobroPedido`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_cobroPedido`(
	in_id_movimiento INT,
	in_cobro DECIMAL(15,2),
	in_cambio DECIMAL(15,2),
	in_descuento DECIMAL(15,2),
	in_forma_pago INT,
	in_factura BOOL,
	in_id_user INT,
	in_id_user_descuento INT,
	in_referencia VARCHAR(20)
)
    SQL SECURITY INVOKER
    COMMENT 'Aplica el cobro a un pedido'
BEGIN
	UPDATE tbl_movimientos
	SET pagado = pagado + in_cobro - in_cambio + in_descuento,
		descuento = descuento + in_descuento,
		fecha_pago = NOW(),
		factura = in_factura,
		id_usuario_pago = in_id_user
	WHERE id_movimiento = in_id_movimiento;
	
	INSERT INTO tbl_movimientos_pagos
	SET id_movimiento = in_id_movimiento,
		importe_cobro = in_cobro,
		cambio = in_cambio,
		descuento = in_descuento,
		id_forma_pago = in_forma_pago,
		fecha_pago = NOW(),
		id_usuario_pago = in_id_user,
		id_usuario_descuento = in_id_user_descuento;
	
	IF TRIM(in_referencia) <> '' THEN
		UPDATE tbl_devoluciones
		SET aplicado = NOW()
		WHERE referencia = in_referencia;
	END IF;
END$$

DELIMITER ;


DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_producto_x_codigo`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_producto_x_codigo`(
	p_codigo VARCHAR(30)
)
    COMMENT 'Búsqueda de Producto por Código'
BEGIN
	SELECT 1 AS cantidad,
		prd.modelo,
		prd.nombre AS descripcion,
		prd.precio_venta AS precio_unitario,
		prd.precio_venta,
		0.00 AS subtotal,
		0.00 AS iva,
		0.00 AS total,
		prd.tasa_iva,
		prd.iva_incluido,
		prd.imagen,
		prd.id_producto,
		prd.clave
	FROM cat_productos_servicios AS prd
	JOIN cat_configuracion AS cfg
	WHERE TRIM(BOTH FROM p_codigo) <> ''
	        AND (
			BINARY prd.clave = p_codigo
			OR prd.codigo_proveedor = p_codigo
			OR BINARY LEFT(prd.clave, cfg.group_len) = p_codigo
			OR BINARY prd.modelo = p_codigo
		);
END$$

DELIMITER ;


DELIMITER $$

DROP PROCEDURE IF EXISTS `stp_syncVentas`$$

CREATE DEFINER=`root`@`localhost` PROCEDURE `stp_syncVentas`(
)
    COMMENT 'Recupera la sig. venta pendiente de sincronizar'
BEGIN
    SELECT m.id_movimiento
    FROM tbl_movimientos AS m
    WHERE m.id_tipo_movimiento = 1
	AND m.total > 0
        AND m.pagado >= m.total
        AND m.fecha_cancelado IS NULL
        AND m.consolidado IS NULL
    ORDER BY m.fecha_pago
    LIMIT 1;
END$$

DELIMITER ;



-- Actualiza el nombre del ultimo script actualizado
UPDATE cat_configuracion
SET last_script = 'SQL_20190329';